| Title: | Import 'REDATAM' Files |
|---|---|
| Description: | Import 'REDATAM' formats into R via the 'Open REDATAM' C++ library. The full context of this project and details about the implementation are available in <doi:10.1017/dap.2025.4> (Open Access). |
| Authors: | Mauricio Vargas Sepulveda [aut, cre] (ORCID: <https://orcid.org/0000-0003-1017-7574>), Lital Barkai [aut], Ivan Krylov [ctb], Arseny Kapoulkine [ctb] ('pugixml' C++ library), Oriental Republic of Uruguay [dtc] (Aggregated census data from 2011) |
| Maintainer: | Mauricio Vargas Sepulveda <[email protected]> |
| License: | Apache License (>= 2) |
| Version: | 2.3.0 |
| Built: | 2026-05-18 18:31:55 UTC |
| Source: | https://github.com/litalbarkai/open-redatam |
Read a DIC or DICX dictionary file directly into R.
read_redatam(dictionary)read_redatam(dictionary)
dictionary |
A character string with the path to the dictionary file. It allows relative paths. |
A list of tibbles, each one representing a table with the census entities (or levels) and their attributes (or variables).
# Read a dictionary file (Uruguay 2011, aggregated) zip <- system.file("extdata", "uru2011mini.zip", package = "redatam") dout <- paste(tempdir(), "uru2011mini", sep = "/") unzip(zip, exdir = dout) read_redatam(paste(dout, "uru2011mini.dic", sep = "/")) # or equivalently read_redatam(paste(dout, "uru2011mini.dicx", sep = "/"))# Read a dictionary file (Uruguay 2011, aggregated) zip <- system.file("extdata", "uru2011mini.zip", package = "redatam") dout <- paste(tempdir(), "uru2011mini", sep = "/") unzip(zip, exdir = dout) read_redatam(paste(dout, "uru2011mini.dic", sep = "/")) # or equivalently read_redatam(paste(dout, "uru2011mini.dicx", sep = "/"))